@@ -4,7 +4,6 @@
  *  libnet.h    -   Network routine library
  *
  *  route|daemon9 <route@infonexus.com>
- *
  */
 
 #ifndef __LIBNET_H
@@ -19,21 +18,22 @@
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <ctype.h>
-#include <arpa/inet.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
-#include <arpa/inet.h>
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
 #include <netinet/tcp.h>
 #include <netinet/udp.h>
+#include <netinet/ip_icmp.h>
+#include <sys/time.h>
 #include <netdb.h>
 #include <errno.h>
+#include <assert.h>
 
 #if (__DEBUG)
 #define DEBUG(fmt, arg...) fprintf(stderr, fmt, ##arg)
 #else
-#define DEBUG(fmt, arg...) do {} while (0)
+#define DEBUG(fmt, arg...)
 #endif
 
 #if (LINUX)
@@ -49,11 +49,19 @@
 #define FIX(n)  htons(n)
 #endif
 
+#define ICMP_H  sizeof(struct icmphdr)
 #define UDP_H   sizeof(struct udphdr)
 #define TCP_H   sizeof(struct tcphdr)
 #define IP_H    sizeof(struct ip)
 #define P_H     sizeof(struct psuedohdr)
 
+#define PR2          0
+#define PR8          1
+#define PR16         2
+#define PRu16        3
+#define PR32         4
+#define PRu32        5
+
 struct psuedohdr
 {
     u_long ip_src;
@@ -63,6 +71,26 @@ struct psuedohdr
     u_short len;
 };
 
+
+
+/*
+ *  Seeds the prand generator with gettimeofday...
+ */
+
+int
+seed_prand();
+
+
+/*
+ *  Returns a psuedorandom positive integer.
+ */
+
+u_long
+get_prand(
+    int
+    );
+
+
 /*
  *  Calculates IPv4 family checksum on packet headers.
  */
@@ -73,6 +101,8 @@ do_checksum(
     int,                /* Protocol */
     int                 /* Packet size */
     );
+
+
 /*
  *  Network byte order into IP address
  *  Previous versions had a memory leak (returned a strdup'd pointer -- strdup
@@ -127,6 +157,7 @@ tcp_check(
     u_long              /* Destination IP address */
     );
 
+
 /*
  *  Fast x86 IP checksum.
  */
@@ -149,42 +180,36 @@ open_raw_sock(
     );
 
 
-/*
- *  Standard Stevens daemon code
- */
-
-void
-daemon();
-
-
 /*
  *  TCP packet assembler.
  */
 
 void
 build_tcp(
-    u_short,            /* Source port */
-    u_short,            /* Destination port */
-    u_long,             /* Sequence Number */
-    u_long,             /* Acknowledgement Number */
-    u_char,             /* Control bits */
-    u_short,            /* Advertised Window Size */
-    u_short,            /* Urgent Pointer */
-    const u_char *,     /* Pointer to packet data (or NULL) */
-    u_char *            /* Pointer to packet header memory */
+    u_short,        /* Source port */
+    u_short,        /* Destination port */
+    u_long,         /* Sequence Number */
+    u_long,         /* Acknowledgement Number */
+    u_char,         /* Control bits */
+    u_short,        /* Advertised Window Size */
+    u_short,        /* Urgent Pointer */
+    const u_char *, /* Pointer to packet data (or NULL) */
+    int,            /* Packet payload size */
+    u_char *        /* Pointer to packet header memory */
     );
 
+
 /*
  * UDP packet assembler.
  */
 
 void
 build_udp(
-    u_short,            /* Packet length */
-    u_short,            /* Source port */
-    u_short,            /* Destination port */
-    const u_char *,     /* Pointer to packet data (or NULL) */
-    u_char *            /* Pointer to packet header memory */
+    u_short,        /* Source port */
+    u_short,        /* Destination port */
+    const u_char *, /* Pointer to packet data (or NULL) */
+    int,            /* Packet payload size */
+    u_char *        /* Pointer to packet header memory */
     );
 
 
@@ -194,22 +219,24 @@ build_udp(
 
 void
 build_ip(
-    u_short,            /* Total packet length */
-    u_short,            /* IP ID */
-    u_short,            /* Fragmentation flags and offset */
-    u_char,             /* TTL */
-    u_char,             /* Protocol */
-    u_long,             /* Source IP Address */
-    u_long,             /* Destination IP Address */
-    const u_char *,     /* Pointer to packet data (or NULL) */
-    u_char *            /* Pointer to packet header memory */
+    u_short,        /* Length of packet data */
+    u_short,        /* IP ID */
+    u_short,        /* Fragmentation flags and offset */
+    u_char,         /* TTL */
+    u_char,         /* Protocol */
+    u_long,         /* Source IP Address */
+    u_long,         /* Destination IP Address */
+    const u_char *, /* Pointer to packet data (or NULL) */
+    int,            /* Packet payload size */
+    u_char *        /* Pointer to packet header memory */
     );
 
-int                     /* 1 if successful, -1 on error */
+
+int                 /* 1 if successful, -1 on error */
 write_ip(
-    int sock,           /* Previously opened raw socket */
-    const u_char *,     /* Pointer a complete IP datagram */
-    int                 /* Packet size */
+    int sock,       /* Previously opened raw socket */
+    const u_char *, /* Pointer a complete IP datagram */
+    int             /* Packet size */
     );
 
 
